==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebLinearProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebLinearProgressDescription } from "./WebLinearProgressDescription";
/**
 * @hidden
 */
var WebLinearProgressDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebLinearProgressDescriptionMetadata, _super);
    function WebLinearProgressDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebLinearProgressDescriptionMetadata.b = function (a) {
        if (WebLinearProgressDescriptionMetadata.a == null) {
            WebLinearProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebLinearProgressDescriptionMetadata.c(WebLinearProgressDescriptionMetadata.a);
        }
        if (a.g(WebLinearProgressDescriptionMetadata.a)) {
            return;
        }
        a.s(WebLinearProgressDescriptionMetadata.a);
    };
    WebLinearProgressDescriptionMetadata.c = function (a) {
        WebProgressBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:LinearProgress");
        a.item("Striped", "Boolean");
        a.item("LabelAlign", "ExportedType:string:LinearProgressLabelAlign");
        a.item("LabelAlign@names", "Top;TopStart;TopEnd;Bottom;BottomStart;BottomEnd");
    };
    WebLinearProgressDescriptionMetadata.d = function (a) {
        WebLinearProgressDescriptionMetadata.b(a);
        a.u("WebLinearProgress", function () { return new WebLinearProgressDescription(); });
        a.t("WebLinearProgress", WebLinearProgressDescriptionMetadata.a);
    };
    WebLinearProgressDescriptionMetadata.$t = markType(WebLinearProgressDescriptionMetadata, 'WebLinearProgressDescriptionMetadata');
    WebLinearProgressDescriptionMetadata.a = null;
    return WebLinearProgressDescriptionMetadata;
}(Base));
export { WebLinearProgressDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebLinearProgressDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebProgressBaseDescriptionMetadata } from "./WebProgressBaseDescriptionMetadata";
import { WebLinearProgressDescription } from "./WebLinearProgressDescription";
/**
 * @hidden
 */
var WebLinearProgressDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebLinearProgressDescriptionMetadata, _super);
    function WebLinearProgressDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebLinearProgressDescriptionMetadata.b = function (a) {
        if (WebLinearProgressDescriptionMetadata.a == null) {
            WebLinearProgressDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebLinearProgressDescriptionMetadata.c(WebLinearProgressDescriptionMetadata.a);
        }
        if (a.j(WebLinearProgressDescriptionMetadata.a)) {
            return;
        }
        a.y(WebLinearProgressDescriptionMetadata.a);
    };
    WebLinearProgressDescriptionMetadata.c = function (a) {
        WebProgressBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:LinearProgress");
        a.item("__tagNameWC", "String:igc-linear-progress");
        a.item("Striped", "Boolean");
        a.item("LabelAlign", "ExportedType:string:LinearProgressLabelAlign");
        a.item("LabelAlign@names", "Top;TopStart;TopEnd;Bottom;BottomStart;BottomEnd");
    };
    WebLinearProgressDescriptionMetadata.d = function (a) {
        WebLinearProgressDescriptionMetadata.b(a);
        a.aa("WebLinearProgress", function () { return new WebLinearProgressDescription(); });
        a.z("WebLinearProgress", WebLinearProgressDescriptionMetadata.a);
    };
    WebLinearProgressDescriptionMetadata.$t = markType(WebLinearProgressDescriptionMetadata, 'WebLinearProgressDescriptionMetadata');
    WebLinearProgressDescriptionMetadata.a = null;
    return WebLinearProgressDescriptionMetadata;
}(Base));
export { WebLinearProgressDescriptionMetadata };
